@@ -13,9 +13,22 @@ The trick:  In Botfather, create /newbot,
  - select a name Btrfs
  - select a username Btrfsbot
 
+- start the bot in telegram - in @Father /mybots,
+  click @Brtfsbot, press start or /start
+
 1- remember the API key
 from API on web
 https://api.telegram.org/bot123456789:AA..4Q/getUpdates
+- already after start it should give chatid
+- chatid seems be the same for all
+
+LEVEL2:
+==================================================
+pip3 install python-telegram-bot
+
+
+OLD:
+==================================================
 - start the bot in telegram - /mybots...
 - possibly send some text from phone...
 /start
